package com.pj.tb_order;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.util.Date;

/**
 * Model: tb_order -- 订单表
 * @author yzs 
 */
@Data
@Accessors(chain = true)
@TableName(TbOrder.TABLE_NAME)
@EqualsAndHashCode(callSuper = false)
public class TbOrder extends Model<TbOrder> implements Serializable {

	// ---------- 模块常量 ----------
	/**
	 * 序列化版本id 
	 */
	private static final long serialVersionUID = 1L;	
	/**
	 * 此模块对应的表名 
	 */
	public static final String TABLE_NAME = "tb_order";	
	/**
	 * 此模块对应的权限码 
	 */
	public static final String PERMISSION_CODE = "tb-order";
	public static final String PERMISSION_CODE_ADD = "tb-order-add";
	public static final String PERMISSION_CODE_EDIT = "tb-order-edit";
	public static final String PERMISSION_CODE_DEL = "tb-order-del";




	// ---------- 表中字段 ----------
	/**
	 * 主键 
	 */
	@TableId(type = IdType.AUTO)
	private Long id;	

	/**
	 * 订单号 
	 */
	private String tradeNo;	

	/**
	 * 交易地区ID 
	 */
	private Long tradeAreaId;	

	/**
	 * 交易地区名称 
	 */
	private String tradeAreaName;	

	/**
	 * 地区ID集合 
	 */
	private String addressIds;	

	/**
	 * 过审商品id 
	 */
	private Long goodsId;	

	/**
	 * 卖家ID 
	 */
	private Long saleMainId;	

	/**
	 * 购买的互市组ID 
	 */
	private Long groupId;	

	/**
	 * 买家ID 
	 */
	private Long buyUserId;	

	/**
	 * 买家 
	 */
	private String buyUserName;	

	/**
	 * 购买用户类型(3=边民,2=组长) 
	 */
	private String buyUserType;	

	/**
	 * 商家ID 
	 */
	private Long enterpriseId;	

	/**
	 * 商家名称 
	 */
	private String enterpriseName;	

	/**
	 * 总重量 
	 */
	private Double totalWeight;	

	/**
	 * 总金额 
	 */
	private Double totalPrice;	

	/**
	 * 交易时间 
	 */
	private Date tradeTime;	

	/**
	 * 交易状态(0=未支付,1=已支付) 
	 */
	private Integer tradeStatus;

	/**
	 * 支付方式(0=金融互助,1=现金刷卡) 
	 */
	private Integer payType;

	/**
	 * 结算时间 
	 */
	private Date settleTime;

	/**
	 * 当前结算金额 
	 */
	private Double realPrice;	

	/**
	 * 应结金额 
	 */
	private Double shouldPrice;	

	/**
	 * 对账人 
	 */
	private Long settleUserId;	

	/**
	 * 对账人员 
	 */
	private Long recordUserId;	

	/**
	 * 对账时间 
	 */
	private String recordTime;	

	/**
	 * 是否对账(0=否,) 
	 */
	private String record;	

	/**
	 * 退款原因 
	 */
	private String refundReason;	

	/**
	 * 退款时间 
	 */
	private Date refundTime;

	/**
	 * 收货人名称 
	 */
	private String receiveName;	

	/**
	 * 收货人电话 
	 */
	private String receivePhone;	

	/**
	 * 收货地址 
	 */
	private String receiveAddress;	

	/**
	 * 出互市区时间 
	 */
	private Date outTime;

	/**
	 * 商品名称字符串 
	 */
	private String goodsNames;	

	/**
	 * 商品图片 
	 */
	private String goodsImg;	

	/**
	 * 申报 
	 */
	private Integer apply;

	/**
	 * 申报时间 
	 */
	private Date applyTime;

	/**
	 * 申报结果 
	 */
	private String applyResult;	

	/**
	 * 申报单号 
	 */
	private Long applyNo;	

	/**
	 * 申报失败理由 
	 */
	private String applyFailReason;	

	/**
	 * 分配方式(0=均分,1=自选数量) 
	 */
	private String distribution;	

	/**
	 * 边民确认 
	 */
	private Integer peopleConfirmStatus;

	/**
	 * 边民确认类型 
	 */
	private String peopleConfirmType;	

	/**
	 * 边民确认时间 
	 */
	private String peopleConfirmTime;	

	/**
	 * 一级市场商户确认(0=待确认,1=是,2=否) 
	 */
	private Integer enterpriseConfirm;

	/**
	 * 是否接单 
	 */
	private String pick;	

	/**
	 * 接单时间 
	 */
	private Date pickTime;

	/**
	 * 商铺ID 
	 */
	private Long shopId;	

	/**
	 * 商铺名称 
	 */
	private String shopName;	

	/**
	 * 是否发货 
	 */
	private Integer send;

	/**
	 * 发货时间 
	 */
	private Date sendTime;

	/**
	 * 对应合作社的拼单订单ID 
	 */
	private Long collageOrdersId;	

	/**
	 * 创建时间 
	 */
	private Date createTime;

	/**
	 * 创建人编号 
	 */
	private Long
			createBy;

	/**
	 * 创建人名称 
	 */
	private String createName;	

	/**
	 * 更新时间 
	 */
	private Date updateTime;

	/**
	 * 更新人编号 
	 */
	private Long updateBy;

	/**
	 * 更新人名称 
	 */
	private String updateName;	

	/**
	 * 删除状态(0=禁用,1=启用) 
	 */
	private Integer deleteStatus;

	/**
	 * 是否转售(0=未转售,1=已转售,2=转售中) 
	 */
	private Integer resaleStatus;

	/**
	 * 订单完成状态(0=未完成,1=已完成) 
	 */
	private Integer finishStatus;

	/**
	 * 边民或组长取消订单(0=未取消,1=已取消) 
	 */
	private Integer cancelPeople;	

	/**
	 * 商品单位 
	 */
	private String goodsUnit;	

	/**
	 * 叫车状态 
	 */
	private Integer callCarStatus;	

	/**
	 * 互助委托申报确认状态 
	 */
	private String cooperEntrustStatus;	

	/**
	 * 互助委托申报确认时间 
	 */
	private Date cooperEntrustTime;

	/**
	 * 边民进口申报确认状态 
	 */
	private String applyConfirmStatus;	

	/**
	 * 边民进口申报确认时间 
	 */
	private Date applyConfirmTime;

	/**
	 * 车牌号 
	 */
	private String veNo;	

	/**
	 * 车航次(班)号 
	 */
	private String voyageNo;	

	/**
	 *  
	 */
	private String preNo;	

	/**
	 * 预申报编号 
	 */
	private String platSeqNo;	

	/**
	 * 边民姓名 
	 */
	private String borderName;	

	/**
	 * 身份证号 
	 */
	private String idno;	

	/**
	 * 边民备案编号 
	 */
	private String borderPutrecNo;	

	/**
	 * 结算单号 
	 */
	private String settleBillNo;	

	/**
	 * 申报金额 
	 */
	private Double buyAmount;	

	/**
	 * 净重 
	 */
	private Double netWt;	

	/**
	 * 毛重 
	 */
	private Double grossWt;	

	/**
	 * 申报数量 
	 */
	private Double buyQty;	

	/**
	 * 第一数量 
	 */
	private Double buyQty1;	

	/**
	 * 第二数量 
	 */
	private Double buyQty2;	

	/**
	 * 进出口预申报单号 
	 */
	private String preIeportNo;	





	


}
